==> worlds_tloz_ph-0.3.2.tar.gz: worlds_tloz_ph-0.3.2/src/worlds/tloz_ph/data/Regions.py <==
REGIONS = [
    "goal",
    "beat required dungeons",

    "mercay island",
    "mercay dig spot",
    "mercay zora cave",
    "mercay zora cave south",
    "mercay freedle island",
    "mercay freedle gift",
    "mercay freedle tunnel chest",
    "mercay yellow guy",
    "mercay passage 1",
    "mercay passage 2",
    "mercay passage 3",
    "mercay passage rat",
    "mercay oshus gem",
    "mercay oshus phantom blade",

    # Mercay ER regions
    "mercay sw",
    "mercay sw bridge",
    "mercay oshus",
    "mercay apricot",
    "mercay sword cave",

    "mercay se",
    "mercay tuzi",
    "mercay milk bar",
    "mercay shop",
    "mercay se cc",
    "mercay se post tof",
    "mercay shipyard",
    "mercay treasure teller",

    # Shop Regions
    "shop power gem",
    "shop bombchu bag",
    "shop quiver",
    "shop heart container",

    "beedle",
    "beedle gem",
    "beedle bomb bag",
    "masked ship hc",
    "masked ship gem",
    "beedle bronze",
    "beedle silver",
    "beedle gold",
    "beedle plat",
    "beedle vip",

    # TotOK
    "totok",
    "totok 1f",
    "totok 1f chest",
    "totok 1f chart",
    
    "totok b1",
    "totok b1 key",
    "totok b1 phantom",
    "totok b1 bow",

    "totok b2",
    "totok b2 key",
    "totok b2 phantom",
    "totok b2 chu",

    "totok b3",
    "totok b3 nw",
    "totok b3 se",
    "totok b3 sw",
    "totok b3 bow",
    "totok b3 key",
    "totok b3 phantom",

    "totok b35",
    "totok b4",
    "totok b4 key",
    "totok b4 eyes",
    "totok b4 phantom",

    "totok b5",
    "totok b5 alt",
    "totok b5 chest",
    "totok b5 alt chest",

    "totok b6",
    "totok b6 bow",
    "totok b6 phantom",
    "totok b6 crest",
    "totok midway",

    "totok b7",
    "totok b7 grapple",
    "totok b7 crystal",
    "totok b7 switch",
    "totok b7 phantom",
    "totok b7 east",

    "totok b8",
    "totok b8 phantom",
    "totok b8 1c",
    "totok b8 2c",
    "totok b8 2c chest",

    "totok b9",
    "totok b9 phantom",
    "totok b9 ghosts",
    "totok b9 corner chest",
    "totok b9 1c",
    "totok b9 2c",

    "totok b10",
    "totok b10 key",
    "totok b10 phantom",
    "totok b10 eye",
    "totok b10 hammer",

    "totok b11",
    "totok b11 phantom",
    "totok b11 eyes",

    "totok b12",
    "totok b12 nw",
    "totok b12 ne",
    "totok b12 phantom",
    "totok b12 ghost",
    "totok b12 hammer",

    "totok b13",
    "totok b13 chest",

    "totok before bellum",
    "bellum 1",
    "ghost ship fight",
    "bellumbeck",
    "beat bellumbeck",

    # SW Ocean
    "sw ocean east",
    "sw ocean west",
    "sw ocean crest salvage",
    "sw ocean frog x",
    "sw ocean frog phi",
    "sw ocean nyave",
    "sw ocean nyave trade",
    "frog warps",

    # Ocean ER
    "mercay boat",
    "cannon boat",
    "ember boat",
    "molida boat",
    "spirit boat",
    "gust boat",
    "bannan boat",
    "uncharted boat",
    "zauz boat",
    "goron boat",
    "frost boat",
    "harrow boat",
    "ds boat",
    "dead boat",
    "maze boat",
    "ruins boat",

    # Cannon Island
    "cannon island",
    "cannon island salvage arm",
    "cannon island dig",

    # Ember ER
    "ember port",
    "ember coast east",
    "ember coast north",
    "ember grapple",
    "ember climb west",
    "ember outside tof",
    "ember summit west",
    "ember summit east",

    "ember astrid",
    "ember astrid basement",
    "ember kayo",
    "ember port house",

    "ember outside tof dig",
    "ember astrid basement dig",
    "ember astrid post tof",

    "ember climb east",
    "ember summit north",


    # Temple of Fire
    "tof 1f",
    "tof 1f keese",
    "tof 1f maze",
    "tof 2f",
    "tof 1f west",
    "tof 1f sw",
    "tof 2f south",
    "tof 3f",
    "tof 3f key drop",
    "tof 3f boss key",
    "tof blaaz",
    "post tof",

    # Molida Island
    "molida island",
    "molida port house",
    "molida dig",
    "molida grapple",
    "molida cave back",
    "molida cave back dig",
    "molida cuccoo dig",
    "molida north",
    "molida north grapple",
    "molida archery",

    # Temple of Courage
    "toc gates",
    "toc",
    "toc bomb alcove",
    "toc b1",
    "toc hammer clips",
    "toc b1 grapple",
    "toc 1f west",
    "toc map room",
    "toc 2f beamos",
    "toc b1 maze",
    "toc south 1f",
    "toc 2f platforms",
    "toc 2f spike corridor",
    "toc torches",
    "toc torches chest",
    "toc pols 2",
    "toc bk room",
    "toc bk chest",
    "toc before boss",
    "toc before boss chest",
    "toc crayk",
    "post toc",

    # Spirit Island
    "spirit island",
    "spirit island gauntlet",
    "spirit power 1",
    "spirit power 2",
    "spirit wisdom 1",
    "spirit wisdom 2",
    "spirit courage 1",
    "spirit courage 2",

    # NW Ocean
    "nw ocean",
    "nw ocean frog n",
    "porl",
    "porl item",
    "porl trade",

    # Isle of Gust
    "gust",
    "gust combat",
    "gust dig",

    # Temple of Wind
    "tow",
    "tow b1",
    "tow b2",
    "tow b2 bombs",
    "tow b2 dig",
    "tow b2 key",
    "tow bk chest",
    "tow cyclok",
    "post tow",

    # Bannan Island
    "bannan",
    "bannan grapple",
    "bannan dig",
    "bannan east",
    "bannan east grapple",
    "bannan east grapple dig",
    "bannan cannon game",
    "bannan scroll",

    # Zauz
    "zauz",
    "zauz dig",
    "zauz crest",
    "zauz blade",

    # Uncharted
    "uncharted",
    "uncharted dig",
    "uncharted cave",
    "uncharted grapple",

    # Ghost Ship
    "ghost ship",
    "ghost ship barrel",
    "ghost ship b2",
    "ghost ship b3",
    "ghost ship cubus",
    "ghost ship tetra",
    "spawn pirate ambush",

    # SE Ocean
    "se ocean",
    "se ocean frogs",
    "se ocean trade",
    "pirate ambush",

    # Goron Island
    "goron",
    "goron port house",
    "goron chus",
    "goron grapple",
    "goron quiz",
    "goron north",
    "goron outside temple",
    "goron north bombchu",
    "goron chief 2",

    # Goron Temple
    "gt",
    "gt 2",
    "gt bow",
    "gt b1",
    "gt b2",
    "gt b2 back",
    "gt b3",
    "gt bk chest",
    "gt dongo",
    "post gt",

    # Harrow Island
    "harrow",
    "harrow sword",
    "harrow dig",
    "harrow dig 2",

    # Dee Ess Island
    "ds",
    "ds dig",
    "ds combat",
    "ds race",

    # Isle of Frost
    "iof",
    "iof smart house",
    "iof grapple",
    "iof dig",
    "iof grapple dig",
    "iof yook",

    # Temple of Ice
    "toi",
    "toi 2f",
    "toi 3f",
    "toi 3f switch",
    "toi 3f boomerang",
    "toi 2f miniboss",
    "toi side path",
    "toi b1",
    "toi b1 2",
    "toi b1 key",
    "toi b2",
    "toi bk chest",
    "toi b2 key",
    "toi gleeok",

    # NE Ocean

    "ne ocean",
    "ne ocean frog",
    "ne ocean combat",
    "ne ocean inner",

    # Isle of the Dead
    "iotd",
    "iotd rupoor",
    "iotd dig",
    "iotd cave",

    # ruins er
    "ruins port",
    "ruins geozard cave east",
    "ruins geozard cave west",
    "ruins sw maze upper",
    "ruins sw maze lower",
    "ruins sw maze lower exit",
    "ruins sw port cliff",

    "ruins nw maze lower exit",
    "ruins nw maze upper exit",
    "ruins nw maze lower chest",
    "ruins nw boulders",
    "ruins nw dig",
    "ruins nw across bridge",
    "ruins nw cave",
    "ruins nw alcove",
    "ruins nw port cliff",
    "ruins nw lower",
    "ruins nw return",

    "bremeur",
    "bremeur kings key",

    "ruins ne doylan bridge",
    "ruins ne lower",
    "ruins ne behind temple",
    "ruins ne enter upper",
    "doylan temple",
    "doylan chamber",
    "ruins ne secret chest",
    "ruins ne geozards",
    "ruins ne outside temple",

    "ruins se lower",
    "ruins se return bridge east",
    "ruins se return bridge west",
    "ruins se outside max",
    "max",
    "ruins se coast",
    "ruins se path to temple",



    # Mutoh's Temple
    "mutoh",
    "mutoh landing",
    "mutoh hammer",
    "mutoh water",
    "mutoh bk chest",
    "mutoh eox",

    # Maze Island
    "maze",
    "maze sword",
    "maze east",
    "maze normal",
    "maze expert",
    "maze dig",

    # Fishing
    'fishing',
    'fishing bcl',
    'fishing shadows',
    'fishing rsf',
    'fishing stowfish',
    'bannan loovar',
    'bannan rsf',
    'bannan neptoona',
    'bannan stowfish',
    'bannan letter',

    # Salvage
    "sw ocean west salvage",
    "sw ocean east salvage",
    "nw ocean salvage",
    "se ocean salvage",
    "ne ocean salvage",
    "ne ocean salvage inner",
    "nw ocean corner salvage",


    "salvage 1",
    "salvage 2",
    "salvage 3",
    "salvage 4",
    "salvage 5",
    "salvage 6",
    "salvage 7",
    "salvage 8",
    "salvage 9",
    "salvage 10",
    "salvage 11",
    "salvage 12",
    "salvage 13",
    "salvage 14",
    "salvage 15",
    "salvage 16",
    "salvage 17",
    "salvage 18",
    "salvage 19",
    "salvage 20",
    "salvage 21",
    "salvage 22",
    "salvage 23",
    "salvage 24",
    "salvage 25",
    "salvage 26",
    "salvage 27",
    "salvage 28",
    "salvage 29",
    "salvage 30",
    "salvage 31",
]


if __name__ == "__main__":
    ocean_lookup = ["SW", "NW", "SE", "NE"]
    for i in range(31):
        print(f"\t\"salvage {i+1}\",")

==> worlds_tloz_ph-0.7.6.tar.gz: worlds_tloz_ph-0.7.6/src/worlds/tloz_ph/data/Regions.py <==
REGIONS = [
    "goal",
    "beat required dungeons",
    "menu",

    "mercay dig spot",
    "mercay freedle island",
    "mercay freedle gift",
    "mercay freedle tunnel chest",
    "mercay freedle tunnel",
    "mercay yellow guy",
    "mercay oshus gem",
    "mercay oshus phantom blade",

    # Mercay ER regions
    "mercay sw",
    "mercay sw bridge",
    "mercay oshus",
    "mercay apricot",
    "mercay sword cave",
    "mercay sw oob east",
    "mercay sw oob high",
    "mercay sw oob low",

    "mercay se",
    "mercay tuzi",
    "mercay milk bar",
    "mercay shop",
    "mercay se cc",
    "mercay se post tof",
    "mercay shipyard",
    "mercay treasure teller",
    "mercay se ledge",
    "mercay se oob",

    "mercay nw chus",
    "mercay nw temple",
    "mercay nw bamboo",
    "mercay nw oob high",
    "mercay nw oob low",
    "mercay geozard cave north",
    "mercay geozard cave south",

    "mercay ne",
    "mercay ne oob",
    "mercay ne ledge",

    # Mercay passage
    "mercay passage 1",
    "mercay passage 2",
    "mercay passage 2 exit",
    "mercay passage 3",
    "mercay passage rat",
    "mercay passage 4",

    # Shop Regions
    "island shop",
    "shop power gem",
    "shop bombchu bag",
    "shop quiver",
    "shop heart container",

    "beedle",
    "beedle gem",
    "beedle bomb bag",
    "masked ship hc",
    "masked ship gem",
    "beedle bronze",
    "beedle silver",
    "beedle gold",
    "beedle plat",
    "beedle vip",

    # TotOK
    "totok",
    "totok 1f",
    "totok 1f chest",
    "totok 1f chart",
    
    "totok b1",
    "totok b1 key",
    "totok b1 phantom",
    "totok b1 bow",

    "totok b2",
    "totok b2 key",
    "totok b2 phantom",
    "totok b2 chu",

    "totok b3",
    "totok b3 nw",
    "totok b3 se",
    "totok b3 sw",
    "totok b3 bow",
    "totok b3 key",
    "totok b3 phantom",

    "totok b35",
    "totok b4",
    "totok b4 key",
    "totok b4 eyes",
    "totok b4 phantom",

    "totok b5",
    "totok b5 alt",
    "totok b5 chest",
    "totok b5 alt chest",

    "totok b6",
    "totok b6 bow",
    "totok b6 phantom",
    "totok b6 crest",
    "totok midway",

    "totok b7",
    "totok b7 grapple",
    "totok b7 crystal",
    "totok b7 switch",
    "totok b7 phantom",
    "totok b7 east",

    "totok b8",
    "totok b8 phantom",
    "totok b8 1c",
    "totok b8 2c",
    "totok b8 2c chest",

    "totok b9",
    "totok b9 phantom",
    "totok b9 ghosts",
    "totok b9 corner chest",
    "totok b9 1c",
    "totok b9 2c",
    "totok b95",

    "totok b10",
    "totok b10 key",
    "totok b10 phantom",
    "totok b10 eye",
    "totok b10 hammer",

    "totok b11",
    "totok b11 phantom",
    "totok b11 eyes",

    "totok b12",
    "totok b12 nw",
    "totok b12 ne",
    "totok b12 phantom",
    "totok b12 ghost",
    "totok b12 hammer",

    "totok b13",
    "totok b13 chest",

    "totok before bellum",
    "bellum 1",
    "ghost ship fight",
    "bellumbeck",
    "beat bellumbeck",

    # SW Ocean
    "sw ocean east",
    "sw ocean west",
    "sw ocean crest salvage",
    "sw ocean frog x",
    "sw ocean frog phi",
    "sw ocean nyave",
    "sw ocean nyave trade",
    "frog warps",

    # Ocean ER
    "mercay boat",
    "cannon boat",
    "ember boat",
    "molida boat",
    "spirit boat",
    "gust boat",
    "bannan boat",
    "uncharted boat",
    "zauz boat",
    "goron boat",
    "frost boat",
    "harrow boat",
    "ds boat",
    "dead boat",
    "maze boat",
    "ruins boat",

    # Cannon Island
    "cannon island",
    "cannon fuzo",
    "cannon eddo",
    "cannon cave south",
    "cannon cave north",
    "cannon island salvage arm",
    "cannon island dig",
    "cannon bomb garden dig",
    "cannon outside eddo",
    "cannon bomb garden",

    # Ember ER
    "ember port",
    "ember coast east",
    "ember coast north",
    "ember grapple",
    "ember climb west",
    "ember outside tof",
    "ember summit west",
    "ember summit east",

    "ember astrid",
    "ember astrid basement",
    "ember kayo",
    "ember port house",

    "ember outside tof dig",
    "ember astrid basement dig",
    "ember astrid post tof",

    "ember climb east",
    "ember summit north",


    # Temple of Fire
    "tof 1f",
    "tof 1f keese",
    "tof 1f maze",
    "tof 2f",
    "tof 1f west",
    "tof 1f sw",
    "tof 2f south",
    "tof 3f",
    "tof 3f key drop",
    "tof 3f key door",
    "tof 3f boss key",
    "tof before blaaz",
    "tof blaaz",
    "post blaaz",
    "post tof",

    # Molida Island
    "molida island",
    "molida port house",
    "molida potato house",
    "molida shop",
    "molida romaros",
    "molida cave",
    "molida cave upper",
    "molida cave drop",
    "molida cave sun door",
    "molida dig",
    "molida cave grapple",
    "molida cave back",
    "molida cave geozard",
    "molida cave geozard dig",
    "molida cave post geozard",
    "molida cave octos",
    "molida shovel cave",
    "molida shovel cave dig",
    "molida cliff north",
    "molida cliff south",
    "molida cuccoo dig",
    "molida north",
    "molida north grapple",
    "molida archery",

    # Temple of Courage
    "toc gates",
    "toc",
    "toc bomb alcove",
    "toc b1",
    "toc hammer clips",
    "toc b1 grapple",
    "toc 1f west",
    "toc map room",
    "toc 2f beamos",
    "toc b1 maze",
    "toc south 1f",
    "toc 2f platforms",
    "toc 2f spike corridor",
    "toc torches",
    "toc torches chest",
    "toc pols 2",
    "toc bk room",
    "toc bk chest",
    "toc before boss",
    "toc before boss chest",
    "toc crayk",
    "post crayk",
    "post toc",

    # Spirit Island
    "spirit island",
    "spirit island gauntlet",
    "spirit cave",
    "spirit power 1",
    "spirit power 2",
    "spirit wisdom 1",
    "spirit wisdom 2",
    "spirit courage 1",
    "spirit courage 2",

    # NW Ocean
    "nw ocean",
    "nw ocean frog n",
    "porl",
    "porl item",
    "porl trade",

    # Isle of Gust
    "gust south",
    "gust hideout",
    "gust cave",
    "gust cave damage",
    "gust cliffs",
    "gust temple road",
    "gust outside temple",
    "gust cliffs dig",
    "gust west",
    "gust above temple",
    "gust west ledge",
    "gust west chest",
    "gust nw",
    "gust nw dig",
    "gust sandworms",

    # Temple of Wind
    "tow",
    "tow b1",
    "tow b2",
    "tow b2 bombs",
    "tow b2 dig",
    "tow b2 key",
    "tow bk chest",
    "tow before boss",
    "tow cyclok",
    "post cyclok",
    "post tow",

    # Bannan Island
    "bannan",
    "bannan wayfarer",
    "bannan cave east",
    "bannan cave west",
    "bannan grapple",
    "bannan dig",
    "bannan east",
    "bannan east grapple",
    "bannan east grapple dig",
    "bannan cannon game",
    "bannan scroll",

    # Zauz
    "zauz",
    "zauz dig",
    "zauz house",
    "zauz crest",
    "zauz blade",

    # Uncharted
    "uncharted",
    "uncharted outside cave",
    "uncharted dig",
    "uncharted cave",
    "uncharted inner cave",
    "uncharted grapple",

    # Ghost Ship
    "ghost ship deck",
    "ghost ship",
    "ghost ship barrel",
    "ghost ship b2",
    "ghost ship b2 chests",
    "ghost ship b3",
    "ghost ship cubus",
    "ghost ship post cubus",
    "ghost ship tetra",
    "spawn pirate ambush",

    # SE Ocean
    "se ocean",
    "se ocean frogs",
    "se ocean trade",
    "pirate ambush",

    # Goron Island
    "goron sw",
    "goron port house",
    "goron shop",
    "goron rock house",
    "goron chu house",
    "goron chu ledge",
    "goron chus",
    "goron grapple",
    "goron shortcut",
    "goron se",
    "goron chief house",
    "goron se house",
    "goron mountain house",
    "goron quiz",
    "goron chief 2",

    "goron ne",
    "goron maze south",
    "goron maze north",
    "goron maze nw",
    "goron maze chu chest",
    "goron maze north dead end",
    "goron maze south dead end",
    "goron maze spikes",
    "goron maze spike chest",
    "goron like like",
    "goron outside temple",

    # Goron Temple
    "gt",
    "gt 2",
    "gt bow",
    "gt b1",
    "gt b2",
    "gt b2 back",
    "gt b3",
    "gt bk chest",
    "gt before dongo",
    "gt dongo",
    "post dongo",
    "post gt",

    # Harrow Island
    "harrow",
    "harrow sword",
    "harrow dig",
    "harrow dig 2",

    # Dee Ess Island
    "ds",
    "ds dig",
    "ds combat",
    "ds race",

    # Isle of Frost
    "frost",
    "frost smart house",
    "frost sensitive house",
    "frost chief house",
    "frost grapple",
    "frost dig",

    "frost estate",
    "frost estate dig",
    "frost estate grapple dig",
    "frost fofo",
    "frost kumu",
    "frost dobo",
    "frost gumo",
    "frost aroo",
    "frost mazo",

    "frost cave",

    "frost field",
    "frost field exit",
    "frost field upper north",
    "frost field upper se",
    "frost field upper chests",
    "frost field east ledge",

    "frost above temple east",
    "frost above temple west",
    "frost outside arena",
    "frost arena",
    "frost outside temple",

    # Temple of Ice
    "toi",
    "toi 1f ascent",
    "toi 1f shortcut",
    "toi 1f descent",
    "toi 1f beetles",
    "toi 2f right",
    "toi 2f left",
    "toi 2f arena",
    "toi 2f post arena",
    "toi 3f right",
    "toi 3f key door",
    "toi 3f",
    "toi 3f switch state",
    "toi 3f boomerang key",

    "toi b1 ascent",
    "toi b1 shore",
    "toi b1 south",
    "toi b1 mid",
    "toi b1 right",
    "toi b1 switch",
    "toi b1 switch room",
    "toi b1 boss door",
    "toi b1 before boss",
    "toi b2",
    "toi b2 north",
    "toi b2 bk chest",
    "toi b2 east",
    "toi b2 bow",
    "toi b2 east arena",
    
    "toi blue warp",
    "gleeok",
    "beat gleeok",
    "post toi",

    # NE Ocean

    "ne ocean",
    "ne ocean frog",
    "ne ocean combat",
    "ne ocean inner",

    # Isle of the Dead
    "iotd port",
    "iotd cave",
    "iotd rupoor",
    "iotd",
    "iotd tunnel",
    "iotd tunnel cave",
    "iotd face",
    "iotd temple",
    "iotd brant maze",
    "iotd brant chamber",
    "iotd crown",

    # ruins er
    "ruins port",
    "ruins geozard cave east",
    "ruins geozard cave west",
    "ruins sw maze upper",
    "ruins sw maze lower",
    "ruins sw maze lower exit",
    "ruins sw port cliff",

    "ruins nw maze lower exit",
    "ruins nw maze upper exit",
    "ruins nw maze lower chest",
    "ruins nw boulders",
    "ruins nw dig",
    "ruins nw across bridge",
    "ruins nw cave",
    "ruins rupee cave",
    "ruins nw alcove",
    "ruins nw port cliff",
    "ruins nw port cliff tree",
    "ruins nw lower",
    "ruins nw return",

    "bremeur",
    "bremeur kings key",

    "ruins ne doylan bridge",
    "ruins ne lower",
    "ruins ne behind temple",
    "ruins ne enter upper",
    "doylan temple",
    "doylan chamber",
    "ruins ne secret chest",
    "ruins ne geozards",
    "ruins ne outside temple",

    "ruins se lower",
    "ruins se return bridge east",
    "ruins se return bridge west",
    "ruins se outside max",
    "max",
    "ruins se coast",
    "ruins se path to temple",



    # Mutoh's Temple
    "mutoh",
    "mutoh landing",
    "mutoh hammer",
    "mutoh water",
    "mutoh bk chest",
    "mutoh before eox",
    "mutoh eox",
    "post eox",
    "mutoh post eox",

    # Maze Island
    "maze",
    "maze sword",
    "maze east",
    "maze normal",
    "maze expert",
    "maze dig",

    # Fishing
    'fishing',
    'fishing bcl',
    'fishing shadows',
    'fishing rsf',
    'fishing stowfish',
    'bannan loovar',
    'bannan rsf',
    'bannan neptoona',
    'bannan stowfish',
    'bannan letter',

    # Salvage
    "sw ocean west salvage",
    "sw ocean east salvage",
    "nw ocean salvage",
    "se ocean salvage",
    "ne ocean salvage",
    "ne ocean salvage inner",
    "nw ocean corner salvage",


    "salvage 1",
    "salvage 2",
    "salvage 3",
    "salvage 4",
    "salvage 5",
    "salvage 6",
    "salvage 7",
    "salvage 8",
    "salvage 9",
    "salvage 10",
    "salvage 11",
    "salvage 12",
    "salvage 13",
    "salvage 14",
    "salvage 15",
    "salvage 16",
    "salvage 17",
    "salvage 18",
    "salvage 19",
    "salvage 20",
    "salvage 21",
    "salvage 22",
    "salvage 23",
    "salvage 24",
    "salvage 25",
    "salvage 26",
    "salvage 27",
    "salvage 28",
    "salvage 29",
    "salvage 30",
    "salvage 31",
]


if __name__ == "__main__":
    ocean_lookup = ["SW", "NW", "SE", "NE"]
    for i in range(31):
        print(f"\t\"salvage {i+1}\",")
